# @description: perform log2 transformation on the data matrix in the current CoolMap view
# @param data: a (non-empty) numeric data matrix.
# @param base: a numeric value for the base of logarithm calculation; 2, exp(1) and 10 are in the dropdown menu

log.transform<-function(data, base=c("2","e","10"))
{
  logbase<-switch(base,"2"=2,"e"=exp(1),"10"=10)

  warning_mssg<-""
  error_mssg<-""
  wmssg<-""
  emssg<-""
  logtransform<-NULL

  exceptions = tryCatch({
    log(data,logbase)
  }, warning = function(war) {
    warning_mssg<<-war
  }, error = function(err) {
    error_mssg<<-err
  }, finally = {
    logtransform<-log(data,logbase)
  })
  if (!is.null(warning_mssg)) wmssg<-sub(" in doTryCatch(return(expr), name, parentenv, handler)", "",warning_mssg, fixed=T) else wmssg<-""
  if (!is.null(error_mssg)) emssg<-sub(" in doTryCatch(return(expr), name, parentenv, handler)", "",error_mssg, fixed=T) else emssg<-""
  list(wmssg=wmssg, emssg=emssg, result=logtransform)
}